@@ -549,7 +549,9 @@ realize (GtkWidget *widget)
     gtk_widget_set_colormap (widget, colormap);
     pixbuf=gdk_pixbuf_new_from_file("/usr/share/omweather/button_icons/nothing.png",&error);
     scaled=gdk_pixbuf_scale_simple(pixbuf,700,700, GDK_INTERP_BILINEAR);
+    g_object_unref(G_OBJECT(pixbuf));
     gdk_pixbuf_render_pixmap_and_mask_for_colormap(scaled,colormap,&background,NULL,0);
+    g_object_unref(G_OBJECT(scaled));
     style = gtk_style_new();
     style->bg_pixmap[0] = background;
     gtk_widget_set_style(GTK_WIDGET(widget),GTK_STYLE(style));
